# MarzbanAPI Client

Это асинхронная библиотека Python для взаимодействия с MarzbanAPI, предоставляющая методы для управления администраторами, пользователями, узлами и системной статистикой.

## Установка

```bash
pip install marzban
```

Project in Pypi - https://pypi.org/project/marzban/

If you notice an error, please create a PR and attach logs
You can contact me by mail contant@sm1ky.com or in Telegram @sm1ky